@@ -144,6 +144,11 @@ def account():
     add_error('Unknown action specified')
     return f.redirect(f.url_for('account'))
 
+@app.route('/users', methods=['GET','POST'])
+@requires_admin()
+def users():
+    pass
+
 @app.route('/login', methods=['GET','POST'])
 def login():
 
